/* Copyright 1997 Lucent Technologies Inc. - All Rights Reserved */

/*
 * makekey - generate a true random key
 * and write it to standard output.
 */

#include <stdio.h>
#include <sys/types.h>

#include "crypto.h"
#include "util.h"
#include "arg.h"

#define MAXKEY	10000

int
usage(void) {
	fprintf(stderr, "usage: makekey [nbytes]\n");
	return 1;
}

int
main(int argc, char *argv[]) {
	DIGEST_CTX context;
	int i;
	int count = KEYLEN;
	u_char key[MAXKEY+20];
	u_long *lp = (u_long *)key;

	ARGBEGIN {
	default:
		return usage();
	} ARGEND;

	if (argc > 0) {
		count = atoi(*argv++);
		argc--;
	}
	if (argc != 0)
		return usage();
	if (count > MAXKEY) {
		fprintf(stderr, "makekey:  key too long, > %d\n", MAXKEY);
		exit(1);
	}

	for (i=0; i<count; i += 4)
		*lp++ = truerand();

	/*
	 * whiten the result
	 */
	for (i=0; i<count; i += 10) {
		HASH_INIT(&context);
		HASH_UPDATE(&context, &key[i], 20);
		HASH_FINAL(&context, key);
	}

	for (i=0; i<count; i++)
		printf("0x%02x, ", key[i]);

	printf("\n");
	return 0;
}
